summaryrefslogtreecommitdiff
path: root/src/lib/regexp/regexp.go
diff options
context:
space:
mode:
authorRob Pike <r@golang.org>2009-03-05 13:31:03 -0800
committerRob Pike <r@golang.org>2009-03-05 13:31:03 -0800
commitef6e0cefc5a2a399f216f4bc2d7998f27a607044 (patch)
tree8260a6a0a0b9e123396885902c49d1856c293c4a /src/lib/regexp/regexp.go
parent914dfea5a0dc5ea0394454f578cbaab72129144a (diff)
downloadgolang-ef6e0cefc5a2a399f216f4bc2d7998f27a607044.tar.gz
delete deprecated files.
deletion beats documentation for deprecation. R=rsc,gri DELTA=509 (2 added, 490 deleted, 17 changed) OCL=25737 CL=25768
Diffstat (limited to 'src/lib/regexp/regexp.go')
-rw-r--r--src/lib/regexp/regexp.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/lib/regexp/regexp.go b/src/lib/regexp/regexp.go
index bfaa999f4..86ef07c2e 100644
--- a/src/lib/regexp/regexp.go
+++ b/src/lib/regexp/regexp.go
@@ -23,9 +23,9 @@
package regexp
import (
- "array";
"os";
"utf8";
+ "vector";
)
var debug = false;
@@ -69,7 +69,7 @@ type Regexp struct {
expr string; // the original expression
ch chan<- *Regexp; // reply channel when we're done
error *os.Error; // compile- or run-time error; nil if OK
- inst *array.Array;
+ inst *vector.Vector;
start instr;
nbra int; // number of brackets in expression, for subexpressions
}
@@ -142,8 +142,8 @@ type _CharClass struct {
common;
char int;
negate bool; // is character class negated? ([^a-z])
- // array of int, stored pairwise: [a-z] is (a,z); x is (x,x):
- ranges *array.IntArray;
+ // vector of int, stored pairwise: [a-z] is (a,z); x is (x,x):
+ ranges *vector.IntVector;
}
func (cclass *_CharClass) kind() int { return _CHARCLASS }
@@ -183,7 +183,7 @@ func (cclass *_CharClass) matches(c int) bool {
func newCharClass() *_CharClass {
c := new(_CharClass);
- c.ranges = array.NewIntArray(0);
+ c.ranges = vector.NewIntVector(0);
return c;
}
@@ -576,7 +576,7 @@ func (re *Regexp) doParse() {
func compiler(str string, ch chan *Regexp) {
re := new(Regexp);
re.expr = str;
- re.inst = array.New(0);
+ re.inst = vector.New(0);
re.ch = ch;
re.doParse();
ch <- re;